@@ -1,13 +1,10 @@
-# p
 from copy import deepcopy
 import requests
 from requests.adapters import SSLError
 import time
 import warnings
 import re
-from disk import Cache, HardFolder
 
-# i
 from chronometry import MeasurementSet, get_elapsed, get_now
 from abstract import Graph
 
@@ -37,6 +34,7 @@ class Wikipedia:
 		self._rate_limit_last_call = None
 		self._num_request_tries = num_request_tries
 
+		self._memory = None
 		self._has_memory = False
 		# if self.has_memory():
 		# 	self._memory = WikipediaMemory(path=self._pickle_path)
@@ -145,6 +143,7 @@ class Wikipedia:
 		_format = format
 		for i in range(1, self._num_request_tries + 1):
 
+			headers = {'User-Agent': self._user_agent}
 			try:
 				if _format == 'json':
 					if parameters is None:
@@ -156,8 +155,6 @@ class Wikipedia:
 					if url is None:
 						raise ValueError('url cannot be empty for non-json request!')
 
-				headers = {'User-Agent': self._user_agent}
-
 				if self._rate_limit_wait and self._rate_limit_last_call:
 					wait_time = self._rate_limit_wait - get_elapsed(start=self._rate_limit_last_call, unit='s')
 					if wait_time > 0:
